#!/bin/bash
# 
# Copyright (C) 2009, Intel Corporation.
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.  
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307 USA.
#
# Authors:
#              Wei, Zhang <wei.z.zhang@intel.com>
#

TMP_FILE_DIR=/tmp/moblin-test-desktop-tmp

# ========================================================================
# directory template
desktop_directory_file_template()
{
echo -e "\
[Desktop Entry]\n
Type=Directory\n
Encoding=UTF-8\n
Name=moblin-test"
}

# ========================================================================
# desktop template 1
# $1: testing target
# $2: name
desktop_entry_file_template_1()
{
echo -e "\
[Desktop Entry]\n
Encoding=UTF-8\n
Type=Application\n
Exec=sh -c 'echo \"$1 pass\" >> /tmp/moblin_desktop.result; echo \"$1 pass\";xterm;'\n
Comment=moblin desktop test: $1\n
Name=$2"
}

# ========================================================================
# desktop template 2
# $1: testing target
# $2: name
# $3: Categories
desktop_entry_file_template_2()
{
echo -e "\
[Desktop Entry]\n
Encoding=UTF-8\n
Type=Application\n
Exec=xterm\n
Comment=moblin desktop test: $1\n
Categories=$3\n
Name=$2"
}

# ========================================================================
# desktop template 3
# $1: testing target
# $2: name
# $3: icon
desktop_entry_file_template_3()
{
echo -e "\
[Desktop Entry]\n
Encoding=UTF-8\n
Type=Application\n
Exec=xterm\n
Icon=$3\n
Comment=moblin desktop test: $1\n
Name=$2"
}

# ========================================================================
# desktop template 4
# $1: testing target
# $2: name
# $3: link url
desktop_entry_file_template_4()
{
echo -e "\
[Desktop Entry]\n
Encoding=UTF-8\n
Type=Link\n
URL=$3\n
Name=$2\n
Comment=moblin desktop test: $1\n"
}

# ========================================================================
# question function
# $1: testing target
# $2: Question
# $3: click
question()
{
    # question and answer
    echo -n $2
    read opt
    if [ "$opt" != "Y" -a "$opt" != "y" ];then
        echo "$1 fail" >> /tmp/moblin_desktop.result
    else
        if $3;then
            echo "Now run the application, and then press ENTER key here to continue..."
            read null
        else
            echo "$1 pass" >> /tmp/moblin_desktop.result
        fi
fi
}

# ========================================================================
# result process function
# $1: testing target
result()
{
    res="`grep \"$1\" /tmp/moblin_desktop.result | awk '{print $2}'`"
    if [ -n "$res" ];then
        echo "$1 $res"
    else
        echo "$1 fail" | tee -a /tmp/moblin_desktop.result
    fi
}

# ========================================================================
# test 01:  possibility to launch an application from file browser
desktop_test_1()
{
    # generate 
    desktop_entry_file_template_1 "launch_from_file_browser" "ClickMe-01" > /tmp/moblin-desktop-test01.desktop -f

    # question and answer
    question "launch_from_file_browser" "Open /tmp with your File Browser, can you see one application named \"ClickMe-01\" or \"moblin-desktop-test01.desktop\"?(Y/N):" true

    # print result
    result "launch_from_file_browser"

    # clean
    rm /tmp/moblin-desktop-test01.desktop -f
}

# ========================================================================
# test 02:  possibility to launch an application from menu
desktop_test_2()
{
    # generate
    desktop_entry_file_template_1 "launch_from_menu" "ClickMe-02" > $TMP_FILE_DIR/moblin-desktop-test02.desktop -f
    desktop_directory_file_template > $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu install $TMP_FILE_DIR/moblin-test.directory $TMP_FILE_DIR/moblin-desktop-test02.desktop

    # question and answer
    question "launch_from_menu" "Open <Applications> menu, can you see one application named \"ClickMe-02\" under sub-menu named \"moblin-test\" or other sub-menu?(Y/N):" true

    # print result
    result "launch_from_menu"

    # clean
    rm $TMP_FILE_DIR/moblin-desktop-test02.desktop -f
    rm $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu uninstall moblin-test.directory moblin-desktop-test02.desktop
}

# ========================================================================
# test 03:  Category test
desktop_test_3()
{
    # generate
    desktop_entry_file_template_2   "category_list"\
                                    "ClickMe-03"\
                                    "Audio Video;Audio;Video;Development;Education;Game;Graphics;Network;Office;Settings;System;Utility;"\
    > $TMP_FILE_DIR/moblin-desktop-test03.desktop -f
    xdg-desktop-menu install $TMP_FILE_DIR/moblin-desktop-test03.desktop

    # question and answer
    question "category_list" "Open <Applications> menu, can you see one application named \"ClickMe-03 in one sub-menu at least\"?(Y/N):" false

    # print result
    result "category_list"

    # clean
    xdg-desktop-menu uninstall moblin-desktop-test03.desktop
    rm $TMP_FILE_DIR/moblin-desktop-test03.desktop -f
}

# ========================================================================
# test 04:  png icon test
desktop_test_4()
{
    # generate
    desktop_entry_file_template_3 "png_icon" "PNG" "/tmp/moblin-desktop-png.png"> $TMP_FILE_DIR/moblin-desktop-png.desktop -f
    desktop_directory_file_template > $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu install $TMP_FILE_DIR/moblin-test.directory $TMP_FILE_DIR/moblin-desktop-png.desktop
    cp $(dirname $0)/moblin.png /tmp/moblin-desktop-png.png -f

    # question and answer
    question "png_icon" "Open <Applications> menu, can you see one application named \"PNG\" with one icon shown under sub-menu named \"moblin-test\" or other sub-menu?(Y/N):" false

    # print result
    result "png_icon"

    # clean
    rm $TMP_FILE_DIR/moblin-desktop-png.desktop -f
    rm $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu uninstall moblin-test.directory moblin-desktop-png.desktop
    rm /tmp/moblin-desktop-png.png -f
}

# ========================================================================
# test 05:  svg icon test
desktop_test_5()
{
    # generate
    desktop_entry_file_template_3 "svg_icon" "SVG" "/tmp/moblin-desktop-svg.svg"> $TMP_FILE_DIR/moblin-desktop-svg.desktop -f
    desktop_directory_file_template > $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu install $TMP_FILE_DIR/moblin-test.directory $TMP_FILE_DIR/moblin-desktop-svg.desktop
    cp $(dirname $0)/moblin.svg /tmp/moblin-desktop-svg.svg -f

    # question and answer
    question "svg_icon" "Open <Applications> menu, can you see one application named \"SVG\" with one icon shown under sub-menu named \"moblin-test\" or other sub-menu?(Y/N):" false

    # print result
    result "svg_icon"

    # clean
    rm $TMP_FILE_DIR/moblin-desktop-svg.desktop -f
    rm $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu uninstall moblin-test.directory moblin-desktop-svg.desktop
    rm /tmp/moblin-desktop-svg.svg -f
}

# ========================================================================
# test 06:  desktop link test
desktop_test_6()
{
    # generate
    desktop_entry_file_template_4 "link" "LINK" "http://www.moblin.org"> /tmp/moblin-desktop-link.desktop -f

    # question and answer
    question "link" "Open /tmp with your File Browser, can you see one application named \"LINK\" or \"moblin-desktop-link.desktop\"? Double-click it to check if browser opened with URL www.moblin.org(Y/N):" false

    # print result
    result "link"

    # clean
    rm /tmp/moblin-desktop-link.desktop -f
}

# ========================================================================
clean()
{
    # test 1 left
    rm /tmp/moblin-desktop-test01.desktop -f
    
    # test 2 left
    rm $TMP_FILE_DIR/moblin-desktop-test02.desktop -f
    rm $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu uninstall moblin-test.directory moblin-desktop-test02.desktop

    # test 3 left
    xdg-desktop-menu uninstall moblin-desktop-test03.desktop
    rm $TMP_FILE_DIR/moblin-desktop-test03.desktop -f

    # test 4 left
    rm $TMP_FILE_DIR/moblin-desktop-png.desktop -f
    rm $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu uninstall moblin-test.directory moblin-desktop-png.desktop
    rm /tmp/moblin-desktop-png.png -f
    
    # test 5 left
    rm $TMP_FILE_DIR/moblin-desktop-svg.desktop -f
    rm $TMP_FILE_DIR/moblin-test.directory -f
    xdg-desktop-menu uninstall moblin-test.directory moblin-desktop-svg.desktop
    rm /tmp/moblin-desktop-svg.svg -f
    
    # test 6 left
    rm /tmp/moblin-desktop-link.desktop -f
}

if [ $# != 1 ];then
    echo "$0 [1-6]|all)"
else
    # create tmp file dir
    mkdir -p $TMP_FILE_DIR
    # clean log
    echo "clean /tmp/moblin_desktop.result..."
    rm /tmp/moblin_desktop.result -f
    touch /tmp/moblin_desktop.result
    chmod 666 /tmp/moblin_desktop.result

    # clean left
    clean

    if [ "$1" == "all" ];then
        desktop_test_1
        desktop_test_2
        desktop_test_3
        desktop_test_4
        desktop_test_5
        desktop_test_6
    else
        desktop_test_$1
    fi
fi
